HmlError

Enum HmlError 

pub enum HmlError<P>
where P: Posn,
{ IoError { span: Span<P>, source: Error, }, MarkupError { span: Span<P>, source: MarkupError, }, ExpectedTagName { span: Span<P>, }, ExpectedWhitespaceAfterTag { span: Span<P>, }, UnexpectedCharacter { span: Span<P>, ch: char, }, UnexpectedTagIndent { span: Span<P>, depth: usize, }, BeyondEndOfTokens, UnexpectedAttribute { span: Span<P>, attr: String, }, UnexpectedNewlineInQuotedString { span: Span<P>, }, ExpectedEquals { span: Span<P>, ch: char, }, UnexpectedEOF { span: Span<P>, }, }
HmlError represents an error from the UTF-8 character reader, either an IO error from the reader or a malformed UTF-8 encoded set of bytes.

Variants



IoError

An IO error

Fields

span: Span<P>

Span of the error

source: Error

Error



MarkupError

A markup error

Fields

span: Span<P>

Span of the error

source: MarkupError

Error



ExpectedTagName

Expected a tag name after hashes

Fields

span: Span<P>

Span of the error



ExpectedWhitespaceAfterTag

Expect whitespace after a tag

Fields

span: Span<P>

Span of the error



UnexpectedCharacter

An unexpected character

Fields

span: Span<P>

Span of the error

ch: char

Character



UnexpectedTagIndent

Expected a depth of N or N+1

Fields

span: Span<P>

Span of the error

depth: usize

Depth



BeyondEndOfTokens

Iterated beyond the end of the reader stream



UnexpectedAttribute

Attribute provided where an attribute was not expected

Fields

span: Span<P>

Span of the error

attr: String

Attribute



UnexpectedNewlineInQuotedString

Newline in a quoted string

Fields

span: Span<P>

Span of the error



ExpectedEquals

Expected an ‘=’ for an attribute but got something else

Fields

span: Span<P>

Span of the error

ch: char

Character



UnexpectedEOF

EOF when it was not expected

Fields

span: Span<P>

Span of the error

Implementations

Source

impl<P> HmlError<P>
where P: Posn,

pub fn unexpected_eof<T>(start: &P, end: &P) -> HmlResult<T, P>

Return an unexpected_eof error at the specified positions

pub fn unexpected_character<T>(start: &P, end: &P, ch: char) -> HmlResult<T, P>

Return an unexpected_character error at the specified positions

pub fn unexpected_newline_in_string<T>(start: &P, end: &P) -> HmlResult<T, P>

Return an unexpected newline error

pub fn expected_equals<T>(start: &P, end: &P, ch: char) -> HmlResult<T, P>

Return an error indicating an expected character, but got a different character

pub fn no_more_events<T>() -> HmlResult<T, P>

Return an error indicating a read beyond the end of the stream

pub fn unexpected_tag_indent<T>(span: Span<P>, depth: usize) -> HmlResult<T, P>

Return an unexpected_tag_indent error over the specified span

pub fn unexpected_attribute<T>( span: Span<P>, prefx: &str, name: &str, ) -> HmlResult<T, P>

Return an unexpected_attribute eror over the given span

pub fn io_error(span: Span<P>, source: Error) -> Self

An IO error

pub fn of_io_result<T>(span: Span<P>, r: Result<T, Error>) -> HmlResult<T, P>

Map a io result over a span to a HmlError result

Source

impl<P> HmlError<P>
where P: Posn,

pub fn span(&self) -> Option<&Span<P>>

Borrow a span if it has one

pub fn map_markup_error<T>( result: MarkupResult<T>, span: &Span<P>, ) -> HmlResult<T, P>

Map a MarkupResult to an HmlResult; this passes an Ok value through unchanged, but it maps an Err to an HmlResult::MarkupError with the provided span