pub enum MarkupError {
EmptyName {},
UnmappedPrefix {
prefix: String,
},
BadName {
name: String,
},
}Expand description
An error representing a tag or name issue when building HML markup; this is not specifically related to a parsing position (indeed, these errors can be generated by using the HML name subsystem without any parsing).
Variants
EmptyName
An empty name was provided, which is illegal
UnmappedPrefix
Use of an unmapped prefix / namespace
BadName
Indicates a bad name (such as a:b:c)
Implementations
Sourceimpl MarkupError
impl MarkupError
Sourcepub fn empty_name() -> Self
pub fn empty_name() -> Self
An ‘empty’ name was provided; names must always contain some characters; create the appropriate error
Sourcepub fn unmapped_prefix(prefix: &str) -> Self
pub fn unmapped_prefix(prefix: &str) -> Self
Create a MarkupError for a specific namespace prefix that has not been mapped in the hierarchy of the document to this point
Sourcepub fn bad_name(name: &str) -> Self
pub fn bad_name(name: &str) -> Self
Create a MarkupError for a malformed name (such as a:b:c)