Event

Enum Event 

pub enum Event<P>{
    StartDocument {
        span: StreamCharSpan<P>,
        version: usize,
    },
    EndDocument {
        span: StreamCharSpan<P>,
    },
    StartElement {
        span: StreamCharSpan<P>,
        tag: Tag,
    },
    EndElement {
        span: StreamCharSpan<P>,
        name: Name,
    },
    Content {
        span: StreamCharSpan<P>,
        ctype: ContentType,
        data: String,
    },
    ProcessingInstruction {
        span: StreamCharSpan<P>,
        name: NSNameId,
        data: Option<String>,
    },
    Comment {
        span: StreamCharSpan<P>,
        data: String,
        lengths: Vec<usize>,
    },
}
A markup event occupying a [Span] on a stream

Variants



StartDocument

The start of the document

Fields

span: StreamCharSpan<P>

File position of start of the document

version: usize

Version as an integer - 100 for 1.00, etc



EndDocument

The end of the document

Fields

span: StreamCharSpan<P>

File position of end of the document



StartElement

Denotes a beginning of an XML element.

Fields

span: StreamCharSpan<P>

The span of the start element ‘tag’

tag: Tag

The actual tag (prefix, URI, name, attributes)



EndElement

Denotes an end of an XML element.

Fields

span: StreamCharSpan<P>

The span of the end element ‘tag’

name: Name

The (prefix, URI, name) of the element (equal to the same value as the StartElement that this closes)



Content

Denotes one part of the content of an element

Fields

span: StreamCharSpan<P>

The span of the content

ctype: ContentType

The type of the content: raw, whitespace, needs unescaping

data: String

The string content



ProcessingInstruction

Denotes an XML processing instruction.

Fields

span: StreamCharSpan<P>

The span of the PI

name: NSNameId

A NSNameId within the namespace that is the name of the processing instruction

data: Option<String>

An optional value for the processing instruction



Comment

Denotes a comment.

Fields

span: StreamCharSpan<P>

The span of the comment

data: String

One string containing all the lines of comment (separated by \n)

The last line does not have \n appended, so single line comments have no newline

lengths: Vec<usize>

Length of each original comment line (not including any additional \n)

Implementations

Source

impl<P> Event<P>

pub fn start_document(span: StreamCharSpan<P>, version: usize) -> Self

Create a StartDocument event

pub fn end_document(span: StreamCharSpan<P>) -> Self

Create an EndDocument event

pub fn start_element(span: StreamCharSpan<P>, tag: Tag) -> Self

Create a StartElement event with a given Tag

pub fn end_element(span: StreamCharSpan<P>, name: Name) -> Self

Create an EndElement event with a given Name

pub fn comment( span: StreamCharSpan<P>, data: String, lengths: Vec<usize>, ) -> Self

Create an event of a vec of comment strings

pub fn content( span: StreamCharSpan<P>, ctype: ContentType, data: String, ) -> Self

Create an event of content of the given type

pub fn content_raw(span: StreamCharSpan<P>, data: String) -> Self

Create an event of raw content

pub fn content_int(span: StreamCharSpan<P>, data: String) -> Self

Create an event of interpretable content

pub fn content_ws(span: StreamCharSpan<P>, data: String) -> Self

Create an event of whitespace content

pub fn get_type(&self) -> EventType

Get the EventType corresponding to the Event

pub fn borrow_span(&self) -> &StreamCharSpan<P>

Borrow the span of the event, for logging or errors etc.

pub fn as_start_document(&self) -> Option<usize>

Return Some(version number) if the Event is a StartDocument event; else return None

pub fn as_start_element(self) -> Option<Tag>

Return Some(Tag) if the Event is a StartElement event; else return None

pub fn as_end_element(&self) -> Option<&Name>

Return Some(Name) if the Event is an EndElement event; else return None

pub fn as_content(&self) -> Option<(ContentType, &str)>

Return Some(ContentType, string) if the Event is a Content event; else return None

pub fn is_start_document(&self) -> bool

Return true if the Event is a StartDocument event

pub fn is_end_document(&self) -> bool

Return true if the Event is an EndDocument event

Source

impl<P> Event<P>

pub fn as_xml_writer<'a>( &'a self, ns: &'a NamespaceStack<'_>, ) -> Option<XmlEvent<'a>>

Get an [xml::writer::XmlEvent<’a>] from this Name

pub fn as_xml_reader( &self, ns: &NamespaceStack<'_>, _fill_namespaces: bool, ) -> Option<XmlEvent>

Get an [xml::reader::XmlEvent<’a>] from this Name