pub enum EventType {
StartDocument,
EndDocument,
StartElement,
EndElement,
Content,
ProcessingInstruction,
Comment,
}Expand description
A markup event
Variants
StartDocument
The start of a document - issued before any other events
EndDocument
The end of a document - issued after all other events; all elements must be closed, and no more events will be returned
StartElement
The start of an element: this is always paired with an [EndElement] event
EndElement
The end of an element
Content
One String of content for an element; will always be within an element
ProcessingInstruction
A processing instruction
Comment
A comment consisting of a String, with new lines between comment lines
There is no trailing newline unless the last line was blank (in which case that new line separates the last-but-one-line from an empty last line)