Attributes

Struct Attributes 

pub struct Attributes { /* private fields */ }
A list of attributes in the order in which they appear in the markup stream

Implementations

Source

impl Attributes

pub fn is_empty(&self) -> bool

Returns true if the Attributes list is empty

pub fn add( &mut self, ns_stack: &mut NamespaceStack<'_>, prefix: &str, name: &str, value: String, ) -> MarkupResult<()>

Add a prefix/name and value to the Attributes list, using the NamespaceStack to resolve the prefix into a URI

pub fn steal(&mut self, v: &mut Self)

Take all the attributes away from another Attributes and add them to this

pub fn take(self) -> Vec<Attribute>

Deconstruct this list of Attribute to a Vec<Attribute>

pub fn attributes(&self) -> &[Attribute]

Borrow the Attribute vec