NamespaceStack

Struct NamespaceStack 

pub struct NamespaceStack<'ns> { /* private fields */ }
A NamespaceStack is a use of a Namespace structure within a document; in general they form a pair, with the Namespace created first and a NamespaceStack following.

The stack consists of frames, which can be pushed and popped. Within a frame there are mappings between prefix strings and URI strings; there will be at most one mapping for each prefix within the frame. Different stack frames may map the same prefix differently, though.

A mapping for a prefix string is determined by finding that mapping in the topmost stack frame if possible; if there is no mapping in that frame, the next frame down is examined, and so on.

URI and prefix strings are stored within the Namespace structure, and are referred to by ’id’s in most of the API - as are mappings from prefix to URI.

A client of the NamespaceStack should add mappings to the NamespaceStack with a [NamespaceStack::add] operation, which returns an NSMap; it can look up mappings for a prefix string by resolving the prefix string to an ID with [NamespaceStack::find_prefix], and then finding the map using NamespaceStack::find_mapping.

A client can iterate through all the mappings using the iter() method.

Example

use hml_rs::names::{NamespaceStack, Namespace};

let mut ns  = Namespace::new(true);
let mut nst = NamespaceStack::new(&mut ns);

Implementations

Source

impl<'ns> NamespaceStack<'ns>

pub fn new(namespaces: &'ns mut Namespace) -> Self

Create a new NamespaceStack, mutably borrowing the Namespace for its lifetime

pub fn uses_xmlns(&self) -> bool

Return true if the Namespace was specified to use the XML namespace (at creation)

pub fn add_null_ns(&mut self)

Add the null namespace

This is normally done at the creation of a NamespaceStack

pub fn add_default_xmls(&mut self)

Add the default XML namespaces to the stack frame

This is normally done at the creation of a NamespaceStack

pub fn push_frame(&mut self)

Push a new stack frame on to the NamespaceStack

pub fn pop_frame(&mut self)

Pop the topmost stack frame from the NamespaceStack

Panics if the stack is empty

pub fn add_mapping_by_id(&mut self, map: NSMap)

Add a mapping of NSPrefixId -> NSUriId to the topmost stack frame

pub fn add_mapping_by_id_if_unset(&mut self, map: NSMap) -> bool

Add a mapping if it does not exist in the topmost stack fram

pub fn find_mapping(&self, prefix_id: NSPrefixId) -> Option<NSUriId>

Find a mapping of an NSPrefixId at the highest level of the stack that it exists

Returns None if there is no mapping on the stack at all

pub fn find_prefix_id(&mut self, prefix: &str) -> Option<NSPrefixId>

Find the NSPrefixId corresponding to a string within the underlying Namespace

pub fn iter_top_mappings(&self) -> NamespaceStackFrameIter<'_>

Get a slice of the mappings of the topmost frame

pub fn borrow_mapping(&self, map: NSMap) -> (&str, &str)

Borrow the two strings corresponding to an NSMap within the Namespace

pub fn name_str(&self, name: NSNameId) -> &str

Borrow the name corresponding to an NSNameId within the Namespace

pub fn prefix_str(&self, prefix: NSPrefixId) -> &str

Borrow the prefix corresponding to an NSPrefixId within the Namespace

pub fn uri_str(&self, uri: NSUriId) -> &str

Borrow the URI corresponding to an NSUriId within the Namespace

pub fn add_name(&mut self, name: &str) -> NSNameId

Add a name for a string to the Namespace; if it is already in the Namespace then it is not added but the current NSNameId is used.

pub fn add_ns(&mut self, prefix: &str, uri: &str) -> NSMap

Add a prefix -> URI mapping to the Namespace

pub fn add_ns_if_unset(&mut self, prefix: &str, uri: &str) -> (NSMap, bool)

Add a prefix -> URI mapping to the Namespace

pub fn fmt_map<W: Write>(&self, w: &mut W, map: NSMap) -> Result<(), Error>

Format an NSMap within the Namespace