Namespace

Struct Namespace 

pub struct Namespace { /* private fields */ }
Namespace is a set of namespace prefixes and URIs, and mappings between them, that have been encountered or are defaults.

It also contains a stack of active mappings

More complex implementations will move to using BTree for the prefixes

Implementations

Source

impl Namespace

pub fn new(xmlns: bool) -> Self

Create a new Namespace object

pub fn uses_xmlns(&self) -> bool

Returns true if the Namespace was constructed indicating it should provide the standard XMLNS

pub fn find_name(&mut self, name: &str) -> Option<NSNameId>

Find a name within the Namespace; return a None if not found, or Some(NSNameId) if it is. An empty name is an NSNameId::None

pub fn find_prefix(&mut self, prefix: &str) -> Option<NSPrefixId>

Find a prefix within the Namespace; return a None if not found, or Some(NSPrefixId) if it is. An empty name is an NSPrefixId::None

pub fn find_uri(&mut self, uri: &str) -> Option<NSUriId>

Find a URI within the Namespace; return a None if not found, or Some(NSUriId) if it is. An empty name is an NSUriId::None

pub fn name_str<'a>(&'a self, name: NSNameId, default: &'a str) -> &'a str

Borrow the str of a NSNameId within the Namespace

pub fn prefix_str<'a>(&'a self, prefix: NSPrefixId, default: &'a str) -> &'a str

Borrow the str of a NSPrefixId within the Namespace

pub fn uri_str<'a>(&'a self, uri: NSUriId, default: &'a str) -> &'a str

Borrow the str of a NSUriId within the Namespace

pub fn add_mapping(&mut self, prefix: &str, uri: &str) -> NSMap

Add a mapping from a prefix to a URI

pub fn add_mapping_by_id( &mut self, prefix_id: NSPrefixId, uri_id: NSUriId, ) -> NSMap

Add a mapping from a prefix to a URI