pub struct Tag {
pub name: Name,
pub attributes: Attributes,
}Expand description
A markup tag consists of a name (possibly within a namespace) and a list of attributes (which are name/value pairs)
Fields
name: NameName with prefix and URI from namespace stack
Note that the Name depends on the Namespace attributes within the tag
attributes: AttributesAttributes for the tag, including any local namespaces for the tag
Implementations
Sourceimpl Tag
impl Tag
Sourcepub fn new(
ns_stack: &mut NamespaceStack<'_>,
ns: &str,
name: &str,
attributes: Attributes,
) -> MarkupResult<Self>
pub fn new( ns_stack: &mut NamespaceStack<'_>, ns: &str, name: &str, attributes: Attributes, ) -> MarkupResult<Self>
Create a new Tag from a namespace and name strings, and an attribute list